/*
 *
 *  Licensed to the Apache Software Foundation (ASF) under one or more
 *  contributor license agreements.  See the NOTICE file distributed with
 *  this work for additional information regarding copyright ownership.
 *  The ASF licenses this file to You under the Apache License, Version 2.0
 *  (the "License"); you may not use this file except in compliance with
 *  the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 */

package org.apache.flex.compiler.internal.config.annotations;

import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

import org.apache.flex.compiler.config.Configuration;

/**
 * This annotation explicitly specifies how a field in {@link Configuration}
 * maps to a configuration option name. The value of the annotation is an array
 * of strings. The strings are ordered elements of an option's canonical names.
 * <p>
 * For example:<br>
 * <code>-compiler.namespaces.namespace</code> <br>
 * maps to <br>
 * <code>@Mapping({"compiler", "namespaces", "namespace"})</code>
 * <p>
 * This annotation is created to decouple the field name in
 * {@link Configuration} and the real option name.
 */
@Retention(value = RetentionPolicy.RUNTIME)
@Target(value = ElementType.METHOD)
public @interface Mapping
{
    String[] value() default {};
}
