/*
 *
 *  Licensed to the Apache Software Foundation (ASF) under one or more
 *  contributor license agreements.  See the NOTICE file distributed with
 *  this work for additional information regarding copyright ownership.
 *  The ASF licenses this file to You under the Apache License, Version 2.0
 *  (the "License"); you may not use this file except in compliance with
 *  the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 */

package org.apache.flex.compiler.problems;

import org.apache.flex.compiler.problems.annotations.DefaultSeverity;
import org.apache.flex.compiler.tree.as.IASNode;

/**
 * Problem generated by </code>Array(value)<code> when <code>value</code>
 * has type <code>*</code>, <code>Object</code>, or <code>Array</code>.
 */
@DefaultSeverity(CompilerProblemSeverity.WARNING)
public final class ArrayDowncastProblem extends SemanticWarningProblem
{
    public static final String DESCRIPTION =
        "To cast a value 'x' to type ${ARRAY}, use the expression 'x as ${ARRAY}' instead of '${ARRAY}(x)'.";

    public static final int warningCode = 5037;

    public ArrayDowncastProblem(IASNode site)
    {
        super(site);
    }
    
    // Prevent these from being localized.
    public final String ARRAY = "Array";
}
